@@ -1,3 +1,4 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.transaction import ReturnedReceivedAchTransactionDTO
 from unit.models.returnAch import *
@@ -5,9 +6,8 @@ from unit.models.codecs import DtoDecoder
 
 
 class ReturnAchResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "returns"
+    def __init__(self, configuration: Configuration):
+        super().__init__("returns", configuration)
 
     def return_ach(self, request: ReturnReceivedAchTransactionRequest) -> Union[UnitResponse[ReturnedReceivedAchTransactionDTO], UnitError]:
         payload = request.to_json_api()
