@@ -1,3 +1,4 @@
+from unit.utils.configuration import Configuration
 from unit.api.base_resource import BaseResource
 from unit.models.webhook import *
 from unit.models.codecs import DtoDecoder
@@ -7,9 +8,8 @@ import base64
 
 
 class WebhookResource(BaseResource):
-    def __init__(self, api_url, token, retries):
-        super().__init__(api_url, token, retries)
-        self.resource = "webhooks"
+    def __init__(self, configuration: Configuration):
+        super().__init__("webhooks", configuration)
 
     def create(self, request: CreateWebhookRequest) -> Union[UnitResponse[WebhookDTO], UnitError]:
         payload = request.to_json_api()
