@@ -13,7 +13,9 @@ class AuthorizationDTO(object):
                  payment_method: Optional[str], digital_wallet: Optional[str], card_verification_data,
                  card_network: Optional[str], tags: Optional[Dict[str, str]],
                  relationships: Optional[Dict[str, Relationship]], merchant_id: Optional[str],
-                 decline_reason: Optional[str], cash_withdrawal_amount: Optional[int]):
+                 decline_reason: Optional[str], cash_withdrawal_amount: Optional[int], summary: Optional[str],
+                 currency_conversion: Optional[CurrencyConversion], rich_merchant_data: Optional[RichMerchantData]
+                 ):
         self.id = id
         self.type = "authorization"
         self.attributes = {"createdAt": created_at, "amount": amount, "cardLast4Digits": card_last_4_digits,
@@ -22,7 +24,9 @@ class AuthorizationDTO(object):
                                                           "id": merchant_id},
                            "recurring": recurring, "paymentMethod": payment_method, "digitalWallet": digital_wallet,
                            "cardVerificationData": card_verification_data, "cardNetwork": card_network, "tags": tags,
-                           "declineReason": decline_reason, "cashWithdrawalAmount": cash_withdrawal_amount}
+                           "declineReason": decline_reason, "cashWithdrawalAmount": cash_withdrawal_amount,
+                           "summary": summary, "currencyConversion": currency_conversion,
+                           "richMerchantData": rich_merchant_data}
         self.relationships = relationships
 
     @staticmethod
@@ -34,7 +38,11 @@ class AuthorizationDTO(object):
                                 attributes.get("paymentMethod"), attributes.get("digitalWallet"),
                                 attributes.get("cardVerificationData"), attributes.get("cardNetwork"),
                                 attributes.get("tags"), relationships, attributes["merchant"].get("id"),
-                                attributes.get("declineReason"), attributes.get("cashWithdrawalAmount"))
+                                attributes.get("declineReason"), attributes.get("cashWithdrawalAmount"),
+                                attributes.get("summary"),
+                                CurrencyConversion.from_json_api(attributes.get("currencyConversion")),
+                                RichMerchantData.from_json_api(attributes.get("richMerchantData"))
+                                )
 
 
 class ListAuthorizationParams(UnitParams):
